<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/paquet-breves?lang_cible=eo
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'breves_description' => 'La fulm-informoj estas mallongaj enhavo, sen aŭtoro.',
	'breves_slogan' => 'Mastrumado de fulm-informoj en SPIP'
);

?>
